==> jei-1.20.1-fabric-15.20.0.117-sources.jar: mezz/jei/common/input/keys/JeiKeyModifier.java <==
package mezz.jei.common.input.keys;

import mezz.jei.common.input.KeyNameUtil;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import net.minecraft.class_437;

public enum JeiKeyModifier {
	CONTROL_OR_COMMAND {
		@Override
		public boolean isActive(JeiKeyConflictContext context) {
			return class_437.method_25441();
		}

		@Override
		public class_2561 getCombinedName(class_3675.class_306 key) {
			if (class_310.field_1703) {
				return class_2561.method_43469("jei.key.combo.command", KeyNameUtil.getKeyDisplayName(key));
			} else {
				return class_2561.method_43469("jei.key.combo.control", KeyNameUtil.getKeyDisplayName(key));
			}
		}
	},
	SHIFT {
		@Override
		public boolean isActive(JeiKeyConflictContext context) {
			return class_437.method_25442();
		}

		@Override
		public class_2561 getCombinedName(class_3675.class_306 key) {
			return class_2561.method_43469("jei.key.combo.shift", KeyNameUtil.getKeyDisplayName(key));
		}
	},
	ALT {
		@Override
		public boolean isActive(JeiKeyConflictContext context) {
			return class_437.method_25443();
		}

		@Override
		public class_2561 getCombinedName(class_3675.class_306 key) {
			return class_2561.method_43469("jei.key.combo.alt", KeyNameUtil.getKeyDisplayName(key));
		}
	},
	NONE {
		@Override
		public boolean isActive(JeiKeyConflictContext context) {
			if (context.conflicts(JeiKeyConflictContext.IN_GAME)) {
				return true;
			}
			return !CONTROL_OR_COMMAND.isActive(context) &&
				!SHIFT.isActive(context) &&
				!ALT.isActive(context);
		}

		@Override
		public class_2561 getCombinedName(class_3675.class_306 key) {
			return KeyNameUtil.getKeyDisplayName(key);
		}
	};

	public abstract boolean isActive(JeiKeyConflictContext context);

	public abstract class_2561 getCombinedName(class_3675.class_306 key);
}

==> jei-1.21.11-fabric-27.4.0.15-sources.jar: mezz/jei/common/input/keys/JeiKeyModifier.java <==
package mezz.jei.common.input.keys;

import mezz.jei.common.input.KeyNameUtil;
import net.minecraft.class_1041;
import net.minecraft.class_11906;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import org.lwjgl.glfw.GLFW;

public enum JeiKeyModifier {
	CONTROL {
		@Override
		public boolean isActive(JeiKeyConflictContext context) {
			class_310 minecraft = class_310.method_1551();
			return minecraft.method_74188();
		}

		@Override
		public class_2561 getCombinedName(class_3675.class_306 key) {
			return class_2561.method_43469("jei.key.combo.control", KeyNameUtil.getKeyDisplayName(key));
		}
	},
	CONTROL_OR_COMMAND {
		@Override
		public boolean isActive(JeiKeyConflictContext context) {
			if (class_11906.field_62586) {
				class_310 minecraft = class_310.method_1551();
				class_1041 window = minecraft.method_22683();
				return class_3675.method_15987(window, GLFW.GLFW_KEY_LEFT_SUPER) || class_3675.method_15987(window, GLFW.GLFW_KEY_RIGHT_SUPER);
			}
			return CONTROL.isActive(context);
		}

		@Override
		public class_2561 getCombinedName(class_3675.class_306 key) {
			if (class_11906.field_62586) {
				return class_2561.method_43469("jei.key.combo.command", KeyNameUtil.getKeyDisplayName(key));
			}
			return CONTROL.getCombinedName(key);
		}
	},
	SHIFT {
		@Override
		public boolean isActive(JeiKeyConflictContext context) {
			class_310 minecraft = class_310.method_1551();
			return minecraft.method_74187();
		}

		@Override
		public class_2561 getCombinedName(class_3675.class_306 key) {
			return class_2561.method_43469("jei.key.combo.shift", KeyNameUtil.getKeyDisplayName(key));
		}
	},
	ALT {
		@Override
		public boolean isActive(JeiKeyConflictContext context) {
			class_310 minecraft = class_310.method_1551();
			return minecraft.method_74189();
		}

		@Override
		public class_2561 getCombinedName(class_3675.class_306 key) {
			return class_2561.method_43469("jei.key.combo.alt", KeyNameUtil.getKeyDisplayName(key));
		}
	},
	NONE {
		@Override
		public boolean isActive(JeiKeyConflictContext context) {
			if (context.conflicts(JeiKeyConflictContext.IN_GAME)) {
				return true;
			}
			return !CONTROL.isActive(context) &&
				!CONTROL_OR_COMMAND.isActive(context) &&
				!SHIFT.isActive(context) &&
				!ALT.isActive(context);
		}

		@Override
		public class_2561 getCombinedName(class_3675.class_306 key) {
			return KeyNameUtil.getKeyDisplayName(key);
		}
	};

	public abstract boolean isActive(JeiKeyConflictContext context);

	public abstract class_2561 getCombinedName(class_3675.class_306 key);
}
